@@ -9,10 +9,10 @@ from easyengine.resources import (
 class EasyEngine(object):
 	name = 'EasyEngine'
 
-	def __init__(self, host, username, password, port=None, *args, **kwargs):
+	def __init__(self, host, username=None, password=None, port=None, *args, **kwargs):
 		self._host     = host
-		self._username = username
-		self._password = password
+		self._username = username if username or None
+		self._password = password if username or None
 		
 		if port:
 			self._port   = int(port)
